pub struct Chat {
pub id: i64,
pub first_name: Option<String>,
pub username: Option<String>,
pub chat_type: String,
}Expand description
Represents a Telegram chat or channel.
This could be a private chat, group, supergroup, or channel.
Fields
id: i64Unique identifier for this chat
first_name: Option<String>First name of the other party in a private chat
username: Option<String>Username of the other party in a private chat
chat_type: StringType of chat (private, group, supergroup, or channel)
Implementations